@@ -414,7 +414,7 @@ class MainWindow(QtWidgets.QMainWindow):
         # Read data
         try:
             if self.mode == "1D":
-                spec_1D = io.read_1D_data(self.fnames["data"])
+                spec_1D = io.read_1D_spectrum(self.fnames["data"])
                 wvlg_1D = spec_1D.spectral_axis
                 flux_1D = spec_1D.flux
 
@@ -521,12 +521,13 @@ class MainWindow(QtWidgets.QMainWindow):
         """
         Load the input line lists and check the format is ok.
         """
+        log.debug(f"Reading absorption lines from: {self.fnames['absorption_lines']}")
         self.abs_lines = ascii_read(self.fnames["absorption_lines"])
-        log.debug(f"Read absorption lines from: {self.fnames['absorption_lines']}")
 
+        log.debug(f"Reading emission lines from: {self.fnames['emission_lines']}")
         self.em_lines = ascii_read(self.fnames["emission_lines"])
-        log.debug(f"Read emission lines from: {self.fnames['emission_lines']}")
 
+        log.debug(f"Reading fine structure lines from: {self.fnames['emission_lines']}")
         self.fs_lines = ascii_read(self.fnames["fine_structure_lines"])
         check = (
             "name" not in self.abs_lines.columns
