@@ -22,7 +22,43 @@ WAVE_KEYS = ["WAVE", "AWAV", "WVLG", "LAM"]
 FLUX_KEYS = ["FLUX"]
 
 
-def read_1D_data(fname):
+def read_line_list(fname):
+    """ """
+    # Make sure fname is a Path instance
+    if not isinstance(fname, Path):
+        fname = Path(fname)
+
+    if not fname.exists():
+        raise Exception("File does not exist")
+
+    tab = ascii_read(fname)
+
+    column_names = list(tab.columns)
+
+    # Wavelength
+    wave_key = __find_column_name(
+        column_names,
+        possible_names=WAVE_KEYS,
+    )
+
+    if wave_key is None:
+        raise Exception(
+            f"Unknown format for file {fname}."
+            " The preferred format is '.ECSV'."
+            " See https://docs.astropy.org/en/stable/io/ascii/ecsv.html"
+        )
+    else:
+        wave_unit = tab[wave_key].unit
+        # Try to get units from the column name
+        wave_unit = __parse_units_from_column_name(wave_key)
+        if wave_unit is None:
+            log.info("No units found for line list wavelength, assuming Angstrom.")
+            tab[wave_key].unit = u.Unit("Angstrom")
+
+    return
+
+
+def read_1D_spectrum(fname):
     """
     A wrapper function to handle case for fits extension or generic txt
     or dat file
@@ -89,6 +125,9 @@ def read_generic_1D_spectrum(fname, wave_unit=None, flux_unit=None):
     flux = None
     uncertainty = None
 
+    wave_unit = None
+    flux_unit = None
+
     if fname.suffix == ".ecsv":
         tab = ascii_read(fname)
         pandas = False
@@ -134,12 +173,6 @@ def read_generic_1D_spectrum(fname, wave_unit=None, flux_unit=None):
             dtype=float,
         )
 
-    # Try to get units from the column name
-    if wave_key is not None:
-        wave_unit = __parse_units_from_column_name(wave_key)
-    if flux_key is not None:
-        flux_unit = __parse_units_from_column_name(flux_key)
-
     # Have to turn to numpy because using pandas series
     if wave_key is not None:
         if pandas:
@@ -147,12 +180,22 @@ def read_generic_1D_spectrum(fname, wave_unit=None, flux_unit=None):
         else:
             waveobs = tab[wave_key]
             wave_unit = waveobs.unit
+
+        # Try to get units from the column name
+        if wave_unit is None:
+            wave_unit = __parse_units_from_column_name(wave_key)
+
     if flux_key is not None:
         if pandas:
             flux = tab[flux_key].to_numpy()
         else:
             flux = tab[flux_key]
             flux_unit = flux.unit
+
+        # Try to get units from the column name
+        if flux_unit is None:
+            flux_unit = __parse_units_from_column_name(flux_key)
+
     if uncertainty_key is not None:
         if pandas:
             uncertainty = tab[uncertainty_key].to_numpy()
